# TextMark


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | **str** |  | 

## Example

```python
from src.client.generated.models.text_mark import TextMark

# TODO update the JSON string below
json = "{}"
# create an instance of TextMark from a JSON string
text_mark_instance = TextMark.from_json(json)
# print the JSON string representation of the object
print(TextMark.to_json())

# convert the object into a dict
text_mark_dict = text_mark_instance.to_dict()
# create an instance of TextMark from a dict
text_mark_from_dict = TextMark.from_dict(text_mark_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


